@@ -2,34 +2,34 @@ import functools
 import inspect
 import itertools
 import warnings
-
-import pkg_resources
+from importlib.metadata import entry_points
 
 from .common import BACKEND_ENTRYPOINTS, BackendEntrypoint
 
 STANDARD_BACKENDS_ORDER = ["netcdf4", "h5netcdf", "scipy"]
 
 
-def remove_duplicates(pkg_entrypoints):
-
+def remove_duplicates(entrypoints):
     # sort and group entrypoints by name
-    pkg_entrypoints = sorted(pkg_entrypoints, key=lambda ep: ep.name)
-    pkg_entrypoints_grouped = itertools.groupby(pkg_entrypoints, key=lambda ep: ep.name)
+    entrypoints = sorted(entrypoints, key=lambda ep: ep.name)
+    entrypoints_grouped = itertools.groupby(entrypoints, key=lambda ep: ep.name)
     # check if there are multiple entrypoints for the same name
-    unique_pkg_entrypoints = []
-    for name, matches in pkg_entrypoints_grouped:
-        matches = list(matches)
-        unique_pkg_entrypoints.append(matches[0])
+    unique_entrypoints = []
+    for name, matches in entrypoints_grouped:
+        # remove equal entrypoints
+        matches = list(set(matches))
+        unique_entrypoints.append(matches[0])
         matches_len = len(matches)
         if matches_len > 1:
-            selected_module_name = matches[0].module_name
-            all_module_names = [e.module_name for e in matches]
+            all_module_names = [e.value.split(":")[0] for e in matches]
+            selected_module_name = all_module_names[0]
             warnings.warn(
                 f"Found {matches_len} entrypoints for the engine name {name}:"
-                f"\n {all_module_names}.\n It will be used: {selected_module_name}.",
+                f"\n {all_module_names}.\n "
+                f"The entrypoint {selected_module_name} will be used.",
                 RuntimeWarning,
             )
-    return unique_pkg_entrypoints
+    return unique_entrypoints
 
 
 def detect_parameters(open_dataset):
@@ -50,12 +50,12 @@ def detect_parameters(open_dataset):
     return tuple(parameters_list)
 
 
-def backends_dict_from_pkg(pkg_entrypoints):
+def backends_dict_from_pkg(entrypoints):
     backend_entrypoints = {}
-    for pkg_ep in pkg_entrypoints:
-        name = pkg_ep.name
+    for entrypoint in entrypoints:
+        name = entrypoint.name
         try:
-            backend = pkg_ep.load()
+            backend = entrypoint.load()
             backend_entrypoints[name] = backend
         except Exception as ex:
             warnings.warn(f"Engine {name!r} loading failed:\n{ex}", RuntimeWarning)
@@ -80,13 +80,13 @@ def sort_backends(backend_entrypoints):
     return ordered_backends_entrypoints
 
 
-def build_engines(pkg_entrypoints):
+def build_engines(entrypoints):
     backend_entrypoints = {}
     for backend_name, backend in BACKEND_ENTRYPOINTS.items():
         if backend.available:
             backend_entrypoints[backend_name] = backend
-    pkg_entrypoints = remove_duplicates(pkg_entrypoints)
-    external_backend_entrypoints = backends_dict_from_pkg(pkg_entrypoints)
+    entrypoints = remove_duplicates(entrypoints)
+    external_backend_entrypoints = backends_dict_from_pkg(entrypoints)
     backend_entrypoints.update(external_backend_entrypoints)
     backend_entrypoints = sort_backends(backend_entrypoints)
     set_missing_parameters(backend_entrypoints)
@@ -95,8 +95,8 @@ def build_engines(pkg_entrypoints):
 
 @functools.lru_cache(maxsize=1)
 def list_engines():
-    pkg_entrypoints = pkg_resources.iter_entry_points("xarray.backends")
-    return build_engines(pkg_entrypoints)
+    entrypoints = entry_points().get("xarray.backends", ())
+    return build_engines(entrypoints)
 
 
 def guess_engine(store_spec):
@@ -126,23 +126,23 @@ def guess_engine(store_spec):
                 f"backends {installed_engines}. Consider explicitly selecting one of the "
                 "installed engines via the ``engine`` parameter, or installing "
                 "additional IO dependencies, see:\n"
-                "http://xarray.pydata.org/en/stable/getting-started-guide/installing.html\n"
-                "http://xarray.pydata.org/en/stable/user-guide/io.html"
+                "https://docs.xarray.dev/en/stable/getting-started-guide/installing.html\n"
+                "https://docs.xarray.dev/en/stable/user-guide/io.html"
             )
         else:
             error_msg = (
                 "xarray is unable to open this file because it has no currently "
                 "installed IO backends. Xarray's read/write support requires "
                 "installing optional IO dependencies, see:\n"
-                "http://xarray.pydata.org/en/stable/getting-started-guide/installing.html\n"
-                "http://xarray.pydata.org/en/stable/user-guide/io"
+                "https://docs.xarray.dev/en/stable/getting-started-guide/installing.html\n"
+                "https://docs.xarray.dev/en/stable/user-guide/io"
             )
     else:
         error_msg = (
             "found the following matches with the input file in xarray's IO "
             f"backends: {compatible_engines}. But their dependencies may not be installed, see:\n"
-            "http://xarray.pydata.org/en/stable/user-guide/io.html \n"
-            "http://xarray.pydata.org/en/stable/getting-started-guide/installing.html"
+            "https://docs.xarray.dev/en/stable/user-guide/io.html \n"
+            "https://docs.xarray.dev/en/stable/getting-started-guide/installing.html"
         )
 
     raise ValueError(error_msg)
@@ -158,13 +158,11 @@ def get_backend(engine):
             )
         backend = engines[engine]
     elif isinstance(engine, type) and issubclass(engine, BackendEntrypoint):
-        backend = engine
+        backend = engine()
     else:
         raise TypeError(
-            (
-                "engine must be a string or a subclass of "
-                f"xarray.backends.BackendEntrypoint: {engine}"
-            )
+            "engine must be a string or a subclass of "
+            f"xarray.backends.BackendEntrypoint: {engine}"
         )
 
     return backend
