@@ -3,6 +3,7 @@ import warnings
 import numpy as np
 import pandas as pd
 
+from ..coding.times import infer_calendar_name
 from .common import (
     _contains_datetime_like_objects,
     is_np_datetime_like,
@@ -15,9 +16,20 @@ from .pycompat import is_duck_dask_array
 def _season_from_months(months):
     """Compute season (DJF, MAM, JJA, SON) from month ordinal"""
     # TODO: Move "season" accessor upstream into pandas
-    seasons = np.array(["DJF", "MAM", "JJA", "SON"])
+    seasons = np.array(["DJF", "MAM", "JJA", "SON", "nan"])
     months = np.asarray(months)
-    return seasons[(months // 3) % 4]
+
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message="invalid value encountered in floor_divide"
+        )
+        warnings.filterwarnings(
+            "ignore", message="invalid value encountered in remainder"
+        )
+        idx = (months // 3) % 4
+
+    idx[np.isnan(idx)] = 4
+    return seasons[idx.astype(int)]
 
 
 def _access_through_cftimeindex(values, name):
@@ -440,6 +452,15 @@ class DatetimeAccessor(Properties):
         "is_leap_year", "Boolean indicator if the date belongs to a leap year.", bool
     )
 
+    @property
+    def calendar(self):
+        """The name of the calendar of the dates.
+
+        Only relevant for arrays of :py:class:`cftime.datetime` objects,
+        returns "proleptic_gregorian" for arrays of :py:class:`numpy.datetime64` values.
+        """
+        return infer_calendar_name(self._obj.data)
+
 
 class TimedeltaAccessor(Properties):
     """Access Timedelta fields for DataArrays with Timedelta-like dtypes.
