@@ -1,17 +1,14 @@
-from distutils.version import LooseVersion
-from typing import TYPE_CHECKING, Generic, Hashable, Mapping, TypeVar, Union
+from __future__ import annotations
+
+from typing import Any, Generic, Mapping
 
 import numpy as np
+from packaging.version import Version
 
 from .options import _get_keep_attrs
 from .pdcompat import count_not_none
 from .pycompat import is_duck_dask_array
-
-if TYPE_CHECKING:
-    from .dataarray import DataArray  # noqa: F401
-    from .dataset import Dataset  # noqa: F401
-
-T_DSorDA = TypeVar("T_DSorDA", "DataArray", "Dataset")
+from .types import T_Xarray
 
 
 def _get_alpha(com=None, span=None, halflife=None, alpha=None):
@@ -40,7 +37,7 @@ def move_exp_nansum(array, *, axis, alpha):
     import numbagg
 
     # numbagg <= 0.2.0 did not have a __version__ attribute
-    if LooseVersion(getattr(numbagg, "__version__", "0.1.0")) < LooseVersion("0.2.0"):
+    if Version(getattr(numbagg, "__version__", "0.1.0")) < Version("0.2.0"):
         raise ValueError("`rolling_exp(...).sum() requires numbagg>=0.2.1.")
 
     return numbagg.move_exp_nansum(array, axis=axis, alpha=alpha)
@@ -79,7 +76,7 @@ def _get_center_of_mass(comass, span, halflife, alpha):
     return float(comass)
 
 
-class RollingExp(Generic[T_DSorDA]):
+class RollingExp(Generic[T_Xarray]):
     """
     Exponentially-weighted moving window object.
     Similar to EWM in pandas
@@ -103,16 +100,16 @@ class RollingExp(Generic[T_DSorDA]):
 
     def __init__(
         self,
-        obj: T_DSorDA,
-        windows: Mapping[Hashable, Union[int, float]],
+        obj: T_Xarray,
+        windows: Mapping[Any, int | float],
         window_type: str = "span",
     ):
-        self.obj: T_DSorDA = obj
+        self.obj: T_Xarray = obj
         dim, window = next(iter(windows.items()))
         self.dim = dim
         self.alpha = _get_alpha(**{window_type: window})
 
-    def mean(self, keep_attrs: bool = None) -> T_DSorDA:
+    def mean(self, keep_attrs: bool = None) -> T_Xarray:
         """
         Exponentially weighted moving average.
 
@@ -139,7 +136,7 @@ class RollingExp(Generic[T_DSorDA]):
             move_exp_nanmean, dim=self.dim, alpha=self.alpha, keep_attrs=keep_attrs
         )
 
-    def sum(self, keep_attrs: bool = None) -> T_DSorDA:
+    def sum(self, keep_attrs: bool = None) -> T_Xarray:
         """
         Exponentially weighted moving sum.
 
