@@ -23,7 +23,7 @@ version = "master"
 def _construct_cache_dir(path):
     import pooch
 
-    if isinstance(path, pathlib.Path):
+    if isinstance(path, os.PathLike):
         path = os.fspath(path)
     elif path is None:
         path = pooch.os_cache(_default_cache_dir_name)
@@ -33,8 +33,8 @@ def _construct_cache_dir(path):
 
 external_urls = {}  # type: dict
 external_rasterio_urls = {
-    "RGB.byte": "https://github.com/mapbox/rasterio/raw/1.2.1/tests/data/RGB.byte.tif",
-    "shade": "https://github.com/mapbox/rasterio/raw/1.2.1/tests/data/shade.tif",
+    "RGB.byte": "https://github.com/rasterio/rasterio/raw/1.2.1/tests/data/RGB.byte.tif",
+    "shade": "https://github.com/rasterio/rasterio/raw/1.2.1/tests/data/shade.tif",
 }
 file_formats = {
     "air_temperature": 3,
@@ -185,7 +185,7 @@ def open_rasterio(
 
     References
     ----------
-    .. [1] https://github.com/mapbox/rasterio
+    .. [1] https://github.com/rasterio/rasterio
     """
     try:
         import pooch
@@ -226,18 +226,27 @@ def load_dataset(*args, **kwargs):
         return ds.load()
 
 
-def scatter_example_dataset():
+def scatter_example_dataset(*, seed=None) -> Dataset:
+    """
+    Create an example dataset.
+
+    Parameters
+    ----------
+    seed : int, optional
+        Seed for the random number generation.
+    """
+    rng = np.random.default_rng(seed)
     A = DataArray(
         np.zeros([3, 11, 4, 4]),
         dims=["x", "y", "z", "w"],
-        coords=[
-            np.arange(3),
-            np.linspace(0, 1, 11),
-            np.arange(4),
-            0.1 * np.random.randn(4),
-        ],
+        coords={
+            "x": np.arange(3),
+            "y": np.linspace(0, 1, 11),
+            "z": np.arange(4),
+            "w": 0.1 * rng.standard_normal(4),
+        },
     )
-    B = 0.1 * A.x ** 2 + A.y ** 2.5 + 0.1 * A.z * A.w
+    B = 0.1 * A.x**2 + A.y**2.5 + 0.1 * A.z * A.w
     A = -0.1 * A.x + A.y / (5 + A.z) + A.w
     ds = Dataset({"A": A, "B": B})
     ds["w"] = ["one", "two", "three", "five"]
